@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-gst.c,v 1.160.2.2 2005/05/17 21:18:02 rbultje Exp $
+ * $Id: bacon-video-widget-gst.c,v 1.160.2.4 2005/09/05 10:10:24 hadess Exp $
  *
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
@@ -1862,7 +1862,7 @@ bacon_video_widget_set_logo (BaconVideoWidget * bvw, gchar * filename)
   bvw->priv->logo_pixbuf = gdk_pixbuf_new_from_file (filename, &error);
 
   if (error) {
-    g_warning ("An error occured trying to open logo %s: %s",
+    g_warning ("An error occurred trying to open logo %s: %s",
                filename, error->message);
     g_error_free (error);
   } else {
@@ -2956,7 +2956,7 @@ bacon_video_widget_new (int width, int height,
   if (!bvw->priv->play) {
     g_set_error (err, bacon_video_widget_error_quark (),
 		 0, _("Failed to create a GStreamer play object"));
-    g_object_unref (G_OBJECT (bvw));
+    g_free (bvw);
     return NULL;
   }
   
@@ -3043,7 +3043,7 @@ bacon_video_widget_new (int width, int height,
     }
     gst_object_unref (GST_OBJECT (video_sink));
     gst_object_unref (GST_OBJECT (audio_sink));
-    g_object_unref (G_OBJECT (bvw));
+    g_free (bvw);
     return NULL;
   }
   /* somehow, alsa hangs? */
