@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.174.2.6 2005/06/18 00:00:43 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.174.2.9 2005/09/05 12:24:50 hadess Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -1279,7 +1279,7 @@ xine_event_message (BaconVideoWidget *bvw, xine_ui_message_data_t *data)
 			return;
 		/* Only if the file could really not be loaded */
 		num = BVW_ERROR_PLUGIN_LOAD;
-		message = g_strdup_printf (_("A problem occured while loading a library or a decoder (%s)."), params);
+		message = g_strdup_printf (_("A problem occurred while loading a library or a decoder (%s)."), params);
 		break;
 	case XINE_MSG_ENCRYPTED_SOURCE:
 		if (g_str_has_prefix (bvw->priv->mrl, "dvd:") != FALSE)
@@ -2459,7 +2459,6 @@ bacon_video_widget_set_show_cursor (BaconVideoWidget *bvw,
 {
 	g_return_if_fail (bvw != NULL);
 	g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
-	g_return_if_fail (bvw->priv->xine != NULL);
 
 	if (show_cursor == FALSE)
 	{
@@ -3569,6 +3568,23 @@ bacon_video_widget_get_current_frame (BaconVideoWidget *bvw)
 		return NULL;
 	}
 
+	switch (ratio) {
+	case XINE_VO_ASPECT_SQUARE:
+		ratio = 10000.0;
+		break;
+	case XINE_VO_ASPECT_4_3:
+		ratio = 10000.0 * 4 / 3;
+		break;
+	case XINE_VO_ASPECT_ANAMORPHIC:
+		ratio = 10000.0 * 16 / 9;
+		break;
+	case XINE_VO_ASPECT_DVB:
+		ratio = 10000.0 * 2.11;
+		break;
+	default:
+		ratio = 0.0;
+	}
+
 	/* Convert to rgb */
 	rgb = yv12torgb (y, u, v, width, height);
 
@@ -3577,10 +3593,6 @@ bacon_video_widget_get_current_frame (BaconVideoWidget *bvw)
 			8, width, height, 3 * width,
 			(GdkPixbufDestroyNotify) g_free, NULL);
 
-	/* MPEG streams have ratio information */
-	ratio = xine_get_stream_info (bvw->priv->stream,
-			XINE_STREAM_INFO_VIDEO_RATIO);
-
 	if (ratio != 10000.0 && ratio != 0.0)
 	{
 		GdkPixbuf *tmp;
