@@ -89,11 +89,12 @@ totem_interface_error_blocking (const char *title, const char *reason,
 	error_dialog = totem_interface_error_dialog (title, reason, parent);
 
 	gtk_dialog_run (GTK_DIALOG (error_dialog));
+	gtk_widget_destroy (error_dialog);
 }
 
 GladeXML *
-totem_interface_load (const char *name, const char *display_name,
-		gboolean fatal, GtkWindow *parent)
+totem_interface_load_with_root (const char *name, const char *root_widget,
+		const char *display_name, gboolean fatal, GtkWindow *parent)
 {
 	GladeXML *glade;
 	char *filename;
@@ -102,7 +103,7 @@ totem_interface_load (const char *name, const char *display_name,
 	filename = totem_interface_get_full_path (name);
 
 	if (filename != NULL)
-		glade = glade_xml_new (filename, NULL, NULL);
+		glade = glade_xml_new (filename, root_widget, GETTEXT_PACKAGE);
 	g_free (filename);
 
 	if (glade == NULL)
@@ -122,6 +123,14 @@ totem_interface_load (const char *name, const char *display_name,
 	return glade;
 }
 
+GladeXML *
+totem_interface_load (const char *name, const char *display_name,
+		gboolean fatal, GtkWindow *parent)
+{
+	return totem_interface_load_with_root (name, NULL, display_name,
+			fatal, parent);
+}
+
 GdkPixbuf*
 totem_interface_load_pixbuf (const char *name)
 {
