@@ -24,6 +24,7 @@
 #define TOTEM_PLAYLIST_H
 
 #include <gtk/gtkdialog.h>
+#include <libgnomevfs/gnome-vfs-volume.h>
 
 G_BEGIN_DECLS
 
@@ -57,8 +58,7 @@ struct TotemPlaylistClass {
 };
 
 GtkType    totem_playlist_get_type (void);
-GtkWidget *totem_playlist_new      (const char *glade_filename,
-				    GdkPixbuf *playing_pix);
+GtkWidget *totem_playlist_new      (void);
 
 /* The application is responsible for checking that the mrl is correct
  * Handles directories, m3u playlists, and shoutcast playlists
@@ -76,6 +76,8 @@ void totem_playlist_save_current_playlist (TotemPlaylist *playlist,
 void       totem_playlist_clear (TotemPlaylist *playlist);
 void       totem_playlist_clear_with_prefix (TotemPlaylist *playlist,
 					     const char *prefix);
+void       totem_playlist_clear_with_gnome_vfs_volume (TotemPlaylist *playlist,
+						       GnomeVFSVolume *volume);
 char      *totem_playlist_get_current_mrl (TotemPlaylist *playlist);
 char      *totem_playlist_get_current_title (TotemPlaylist *playlist,
 					     gboolean *custom);
