@@ -15,6 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ *
+ * The Totem project hereby grant permission for non-gpl compatible GStreamer
+ * plugins to be used and distributed together with GStreamer and Totem. This
+ * permission are above and beyond the permissions granted by the GPL license
+ * Totem is covered by.
+ *
+ * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * See license_change file for details.
+ *
  */
 
 
@@ -56,6 +65,8 @@ static guint totem_remote_signals[LAST_SIGNAL] = { 0 };
 static GIOChannel *lirc_channel = NULL;
 static GList *listeners = NULL;
 
+G_DEFINE_TYPE(TotemRemote, totem_remote, G_TYPE_OBJECT)
+
 static TotemRemoteCommand
 totem_lirc_to_command (const gchar *str)
 {
@@ -172,7 +183,7 @@ totem_remote_finalize (GObject *object)
 }
 
 static void
-totem_remote_class_init (TotemRemote *klass)
+totem_remote_class_init (TotemRemoteClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
@@ -221,33 +232,6 @@ totem_remote_init (TotemRemote *remote)
 	listeners = g_list_prepend (listeners, remote);
 }
 
-GType
-totem_remote_get_type (void)
-{
-	static GType type = 0;
-                                                                              
-	if (type == 0)
-	{ 
-		static GTypeInfo info =
-		{
-			sizeof (TotemRemoteClass),
-			NULL, 
-			NULL,
-			(GClassInitFunc) totem_remote_class_init, 
-			NULL,
-			NULL, 
-			sizeof (TotemRemote),
-			0,
-			(GInstanceInitFunc) totem_remote_init
-		};
-		
-		type = g_type_register_static (G_TYPE_OBJECT, "TotemRemote",
-					       &info, 0);
-	}
-
-	return type;
-}
-
 TotemRemote *
 totem_remote_new (void)
 {
